Crate mdream

Crate mdream 

Re-exports

pub use types::CleanConfig;
pub use types::ExtractionConfig;
pub use types::FilterConfig;
pub use types::FrontmatterConfig;
pub use types::HTMLToMarkdownOptions;
pub use types::IsolateMainConfig;
pub use types::MdreamResult;
pub use types::OutputFormat;
pub use types::PluginConfig;
pub use types::TagOverrideConfig;
pub use types::TailwindConfig;
pub use consts::get_tag_id;

Modules

consts
splitter
types

Structs

MarkdownStreamProcessor
Streaming HTML-to-Markdown converter.

Functions

html_to_format
Convert HTML to the requested output format in a single pass.
html_to_format_result
Convert HTML to the requested format with full results (extraction, frontmatter).
html_to_html
Convert HTML to allowlisted semantic HTML in a single pass.
html_to_markdown
Convert HTML to Markdown in a single pass.
html_to_markdown_result
Convert HTML to Markdown with full results (extraction, frontmatter).
html_to_text
Convert HTML to readable plain text in a single pass.
html_to_text_result
Convert HTML to plain text with full results (extraction, frontmatter).