Re-exports
pub use types::CleanConfig;pub use types::ExtractionConfig;pub use types::FilterConfig;pub use types::FrontmatterConfig;pub use types::HTMLToMarkdownOptions;pub use types::IsolateMainConfig;pub use types::MdreamResult;pub use types::OutputFormat;pub use types::PluginConfig;pub use types::TagOverrideConfig;pub use types::TailwindConfig;pub use consts::get_tag_id;
Modules
Structs
- Markdown
Stream Processor - Streaming HTML-to-Markdown converter.
Functions
- html_
to_ format - Convert HTML to the requested output format in a single pass.
- html_
to_ format_ result - Convert HTML to the requested format with full results (extraction, frontmatter).
- html_
to_ html - Convert HTML to allowlisted semantic HTML in a single pass.
- html_
to_ markdown - Convert HTML to Markdown in a single pass.
- html_
to_ markdown_ result - Convert HTML to Markdown with full results (extraction, frontmatter).
- html_
to_ text - Convert HTML to readable plain text in a single pass.
- html_
to_ text_ result - Convert HTML to plain text with full results (extraction, frontmatter).